# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.utils.encoding import python_2_unicode_compatible
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel


@python_2_unicode_compatible
class Vat(DateModel, UserModel, StatusModel, OrderedModel):
    """
    Stores vats: value added tax
    """
    code = models.CharField(
        unique=True,
        max_length=15,
        verbose_name=_('Code'),
    )
    name = models.CharField(
        unique=True,
        max_length=100,
        verbose_name=_('Name'),
    )
    slug = models.SlugField(
        db_index=True,
        max_length=200,
        verbose_name=_("Slug"),
        help_text=_("Used for URLs, auto-generated from name if blank"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('Description'),
    )
    aliquot_perc = models.DecimalField(
        max_digits=4,
        decimal_places=2,
        default=0,
        verbose_name=_("aliquot perc"),
    )
    deduct_perc = models.DecimalField(
        max_digits=4,
        decimal_places=2,
        default=0,
        verbose_name=_("deduct perc"),
    )

    class Meta:
        verbose_name = _('VAT rate')
        verbose_name_plural = _('VAT rates')
        ordering = ('ordering', 'name')

    def __str__(self):
        return "%s" % self.name
